@@ -23,9 +23,6 @@
 #include <config.h>
 #include <string.h>
 #include <unistd.h>
-
-#include <glade/glade.h>
-
 #include "file-utils.h"
 #include "fr-stock.h"
 #include "main.h"
@@ -134,7 +131,7 @@ extract_cb (GtkWidget   *w,
 						   GTK_DIALOG_DESTROY_WITH_PARENT,
 						   NULL,
 						   _("Extraction not performed"),
-						   message);
+						   "%s", message);
 			gtk_dialog_run (GTK_DIALOG (d));
 			gtk_widget_destroy (GTK_WIDGET (d));
 
@@ -168,7 +165,8 @@ extract_cb (GtkWidget   *w,
 	/* check extraction directory permissions. */
 
 	if (uri_is_dir (extract_to_dir)
-	    && ! check_permissions (extract_to_dir, R_OK | W_OK | X_OK)) {
+	    && ! check_permissions (extract_to_dir, R_OK | W_OK)) 
+	{
 		GtkWidget *d;
 		char      *utf8_path;
 
